/*
 * CPSC 601.28 - Lecture 4 - Arrays and Images
 * Code by David Ledo (dledomai@ucalgary.ca)
 * To run each example/exercise, uncomment desired line and run code
 * Make sure you comment out the other function calls
 */

// Constants
final int SCREEN_WIDTH = 800;
final int SCREEN_HEIGHT = 800;

// Variables
color red = #BE1E2D;
color blue = #308FE0;
color yellow = #FFC531;
color orange = #FF8221;
color green = #5FDB37;
    
color[] colors = { red, blue, yellow, orange, green };

PImage nyc;
PImage ts;

void setup()
{
  size(SCREEN_WIDTH, SCREEN_HEIGHT);
  background(255,255,255);
  
  // always load images in setup!
  nyc = loadImage("NYC.jpg");
  ts = loadImage("TS.jpg");
  
  // arraysNaive();
  // arraysBetter();
  
  // arraysAndColors();
  // arraysRandomColors();

}

/**
 * Draws rectangles of different colors
 * while traversing through an array of colors (global)
 */
void arraysAndColors()
{
  noStroke();
  for(int i = 0; i < colors.length; i++)
  {
    // pick one of the colors
    fill(colors[i]);
    // position it on the screen
    rect((100 * (i + 1) + i* 10), 100, 100, 100);
  } 
}

/**
 * Draws 8 rectangles of random colors from a list (array)
 */
void arraysRandomColors()
{
 for(int i = 0; i < 8; i++)
 {
   // pick a random color from the array of colors
   int fillIndex = int(random(colors.length));
   fill(colors[fillIndex]);
   
   // position the rectangle
   rect((100 * (i + 1) + i* 10), 100, 100, 100);
 }
}

/**
 * Filters a value so that it is not between 30 and 80.
 * this will used to ensure our elipse is either in a small range or
 * a large range
 *
 * Parameters:
 *
 * float value - a number to be filtered
 *
 * returns true if value is outside the range between 30 and 80
 * otherwise returns false
 */
boolean isInRange(float value)
{
  boolean result;
  if(value > 30 && value < 80)
  {
    result = false;
  }
  else
  {
    result = true; 
  }
  return result;
  
  // this whole code can be summarized in one line too:
  // return (value <= 30 || value >= 80);
  // meaning: return true if the value is less than or equal to 30
  // OR if the value is greater than or equal to 80
}

/**
 * Draws ellipses in random locations and random colors
 * size of the ellipse is also random and gets filtered
 * through a function
 */
void randomExample()
{
 // float x = random(800);
    float x = random(0, SCREEN_WIDTH);
    float y = random(0, SCREEN_HEIGHT);
    float size = random(20, 100);
    
    if(isInRange(size))
    {
      byte red = byte(random(0, 255));
      byte green = byte(random(0, 255));
      byte blue = byte(random(0, 255));
    
      noStroke();
      // fill(190, 30, 45, 80);
      fill(red, green, blue, 80); 
      ellipse(x, y, size, size);
    }

}

/**
 * Prints grades for five students
 */
void arraysBetter()
{
  int[] studentGrades = {100, 89, 84, 76, 50, 94};
  
  float average = 0;
  
  for(int i = 0; i < studentGrades.length; i++)
  {
    println("Student " + i + " Grade is " + studentGrades[i]);
    average = average + studentGrades[i];
    //average += studentGrades[i]; // this line does the same as the one above
  } 
  
 average = average / studentGrades.length;
 
 println("Class Average = " + average);
 
}

/**
 * Prints grades for students
 * note that this solution is not the best. It's an example to show why
 * it makes sense to have arrays
 */
void arraysNaive()
{
  int student1Grades = 100;
  int student2Grades = 89;
  int student3Grades = 84;
  int student4Grades = 76;
  int student5Grades = 50;
  
  float average = (student1Grades + student2Grades + student3Grades + student4Grades + student5Grades) / 5;
  
  println("Student 1 Grade = " + student1Grades);
  println("Student 2 Grade = " + student2Grades);
  println("Student 3 Grade = " + student3Grades);
  println("Student 4 Grade = " + student4Grades);
  println("Student 5 Grade = " + student5Grades);
  
  println("-----");
  println("CLASS AVERAGE = " + average);
  
}

/**
 * Draws two images and may apply filters
 * in order to apply filters uncomment the lines of code
 */
void drawImages()
{
  // filter(BLUR, 50);
  // tint(100, 50);
   image(nyc, 10, 10, 500, 500);
  // noTint();
  // tint(255, 50);
   image(ts, 300, 300, 500, 500);
  // noTint();
}

void draw()
{
  randomExample();
  // drawImages();
}
